# -*-makefile-*-
# $Id$
#
# (c) 2003 by Robert Schwebel <r.schwebel@pengutronix.de>
#             Pengutronix <info@pengutronix.de>, Germany
#          
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXDIST project and license conditions
# see the README file.
#

#
# We provide this package
#
ifdef PTXCONF_GTK22
PACKAGES += gtk22
endif

#
# Paths and names
#
GTK22_VERSION		= 2.2.2
GTK22			= gtk+-$(GTK22_VERSION)
GTK22_SUFFIX		= tar.gz
GTK22_URL		= ftp://ftp.gtk.org/pub/gtk/v2.2/$(GTK22).$(GTK22_SUFFIX)
GTK22_SOURCE		= $(SRCDIR)/$(GTK22).$(GTK22_SUFFIX)
GTK22_DIR		= $(BUILDDIR)/$(GTK22)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

gtk22_get: $(STATEDIR)/gtk22.get

gtk22_get_deps	=  $(GTK22_SOURCE)

$(STATEDIR)/gtk22.get: $(gtk22_get_deps)
	@$(call targetinfo, gtk22.get)
	touch $@

$(GTK22_SOURCE):
	@$(call targetinfo, $(GTK22_SOURCE))
	@$(call get, $(GTK22_URL))

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

gtk22_extract: $(STATEDIR)/gtk22.extract

gtk22_extract_deps	=  $(STATEDIR)/gtk22.get

$(STATEDIR)/gtk22.extract: $(gtk22_extract_deps)
	@$(call targetinfo, gtk22.extract)
	@$(call clean, $(GTK22_DIR))
	@$(call extract, $(GTK22_SOURCE))
	touch $@

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

gtk22_prepare: $(STATEDIR)/gtk22.prepare

#
# dependencies
#
gtk22_prepare_deps =  \
	$(STATEDIR)/gtk22.extract \
	$(STATEDIR)/atk124.install \
#	$(STATEDIR)/fontconfig22.install \
#	$(STATEDIR)/virtual-xchain.install

GTK22_PATH	=  PATH=$(CROSS_PATH)
GTK22_ENV 	=  $(CROSS_ENV)
GTK22_ENV	+= PKG_CONFIG_PATH=../$(GLIB22):../$(PANGO12):../$(ATK124):../$(GTK22):../$(FREETYPE214):../$(FONTCONFIG22)
#GTK22_ENV	+= CFLAGS=-I$(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include

# FIXME: gtk+ doesn't use pkg-config yet, so we have to do this. 
GTK22_ENV	+= ac_cv_path_FREETYPE_CONFIG=$(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/bin/freetype-config

#
# autoconf
#
GTK22_AUTOCONF	=  --prefix=/usr
GTK22_AUTOCONF	+= --build=$(GNU_HOST)
GTK22_AUTOCONF	+= --host=$(PTXCONF_GNU_TARGET)
GTK22_AUTOCONF	+= --x-includes=$(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include

# FIXME
GTK22_AUTOCONF	+= --without-libtiff
GTK22_AUTOCONF	+= --without-libjpeg

ifdef PTXCONF_GTK22_FOO
GTK22_AUTOCONF	+= --enable-foo
endif

$(STATEDIR)/gtk22.prepare: $(gtk22_prepare_deps)
	@$(call targetinfo, gtk22.prepare)
	@$(call clean, $(GTK22_BUILDDIR))
	cd $(GTK22_DIR) && \
		$(GTK22_PATH) $(GTK22_ENV) \
		./configure $(GTK22_AUTOCONF)
	touch $@

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

gtk22_compile: $(STATEDIR)/gtk22.compile

gtk22_compile_deps =  $(STATEDIR)/gtk22.prepare

$(STATEDIR)/gtk22.compile: $(gtk22_compile_deps)
	@$(call targetinfo, gtk22.compile)
	
	$(GTK22_PATH) $(GTK22_ENV) make -C $(GTK22_DIR)
	
	# FIXME: this seems not to be generated; mozilla needs it. 
	cd $(GTK22_PATH) && ln -s gdk-2.0-uninstalled.pc gdk-x11-2.0-uninstalled.pc

	touch $@

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

gtk22_install: $(STATEDIR)/gtk22.install

$(STATEDIR)/gtk22.install: $(STATEDIR)/gtk22.compile
	@$(call targetinfo, gtk22.install)
	
	# gdk: FIXME: where to install? 
	install -d $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk/.libs/libgdk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	ln -sf libgdk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgdk-x11-2.0.so.0
	ln -sf libgdk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgdk-x11-2.0.so
	install -d $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gdk
	cp -f $(GTK22_DIR)/gdk/*.h $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gdk/
	cp -f $(GTK22_DIR)/gdk/x11/gdkx.h $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gdk/

	# gdk-pixbuf
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libgdk_pixbuf-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	ln -sf libgdk_pixbuf-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgdk_pixbuf-2.0.so.0
	ln -sf libgdk_pixbuf-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgdk_pixbuf-2.0.so
	install -d $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gdk-pixbuf
	cp -f $(GTK22_DIR)/gdk-pixbuf/*.h $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gdk-pixbuf

	# gdk-pixbuf loaders
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ani.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-bmp.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-gif.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ico.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-png.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-pnm.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ras.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-tga.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-wbmp.so $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-xbm.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-xpm.so  $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib

	# gtk
	cp -f $(GTK22_DIR)/gtk/.libs/libgtk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib
	ln -sf libgtk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgtk-x11-2.0.so.0
	ln -sf libgtk-x11-2.0.so.0.200.2 $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/libgtk-x11-2.0.so
	rm -fr $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/lib/gtk
	install -d $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gtk
	cp -af $(GTK22_DIR)/gtk/*.h $(PTXCONF_PREFIX)/$(PTXCONF_GNU_TARGET)/include/gtk/

	touch $@

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

gtk22_targetinstall: $(STATEDIR)/gtk22.targetinstall

gtk22_targetinstall_deps	=  $(STATEDIR)/gtk22.compile

$(STATEDIR)/gtk22.targetinstall: $(gtk22_targetinstall_deps)
	@$(call targetinfo, gtk22.targetinstall)
	
	# gdk: FIXME: where to install? 
	install -d $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk/.libs/libgdk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib
	ln -sf libgdk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib/libgdk-x11-2.0.so.0
	ln -sf libgdk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib/libgdk-x11-2.0.so
	
	# gdk-pixbuf
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libgdk_pixbuf-2.0.so.0.200.2 $(ROOTDIR)/lib
	ln -sf libgdk_pixbuf-2.0.so.0.200.2 $(ROOTDIR)/lib/libgdk_pixbuf-2.0.so.0
	ln -sf libgdk_pixbuf-2.0.so.0.200.2 $(ROOTDIR)/lib/libgdk_pixbuf-2.0.so
	
	# gdk-pixbuf loaders
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ani.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-bmp.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-gif.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ico.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-png.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-pnm.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-ras.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-tga.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-wbmp.so $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-xbm.so  $(ROOTDIR)/lib
	cp -f $(GTK22_DIR)/gdk-pixbuf/.libs/libpixbufloader-xpm.so  $(ROOTDIR)/lib

	cp -f $(GTK22_DIR)/gtk/.libs/libgtk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib
	ln -sf libgtk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib/libgtk-x11-2.0.so.0
	ln -sf libgtk-x11-2.0.so.0.200.2 $(ROOTDIR)/lib/libgtk-x11-2.0.so
	rm -fr $(ROOTDIR)/lib/gtk
	
	# examples
        ifeq (y, $(PTXCONF_GTK22_EXAMPLES))
	install -d $(ROOTDIR)/opt/gtk+-2.2.2
	cp -fa $(GTK22_DIR)/examples $(ROOTDIR)/opt/gtk+-2.2.2
        endif

	touch $@

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

gtk22_clean:
	rm -rf $(STATEDIR)/gtk22.*
	rm -rf $(GTK22_DIR)

# vim: syntax=make
